flexi_fonts library

Classes

FlexiFontController
Controller class for managing font selection and persistence
FlexiFontSelectorWidget
A widget that displays a list of available fonts and allows the user to select one
FontCategoryFilter
A widget for filtering fonts by category
FontOption
Class representing a font option with its properties
FontPreviewItem
A widget that displays a preview of a font option
FontScaleSlider
A widget that allows the user to adjust the font scale
FontStorageUtils
Utility class for font storage operations
RtlUtils
Utility class for RTL text support
SharedPreferencesStorage
Implementation of StorageProvider using SharedPreferences
StorageProvider
Abstract class for storage providers

Enums

FontCategory
Enum representing different font categories